#version 330 core
//Darkness Shader
//Fragment SHADER

struct Material {
	vec3 ambientColor;			//Ambiente Farbe
	bool diffuseHasTexture;		//Gibt an, ob es eine Diffus-Textur gibt
	vec3 diffuseColor;			//Falls keine Textur: Diffus-Farbe
	sampler2D texture;			//Ansonsten: Textur
	vec3 specularColor;			//Specular-Farbe
	float shininess;			//Specular-Shininess
	float opacity;				//Undurchsichtbarkeit
};
//In: UV
in vec2 fUv;
//In: Normale
in vec3 fNormal;
//In: Richtung zum Auge
in vec3 fEye;
//In: Position
in vec3 fPosition;

//Out: Farbe
layout (location = 0) out vec4 fragColor;
//Out: Glow-Farbe
layout (location = 1) out vec4 brightColor;

//Uniform: Material des Objektes
uniform Material material;
//Uniform: Model-Matrix
uniform mat4 model;
//Uniform: Kameraposition
uniform vec3 eyePos;

#define INTENSITY vec3(0.4, 0.3, 0.3)

vec3 calcLight() {
	vec3 l = eyePos - fPosition;
	float fDistance = length(l);
	l = normalize(l);
	vec3 normal = normalize(fNormal);
	vec3 intensity = max(INTENSITY - fDistance/15, 0);
	float nl = dot(normal, l);
	vec3 diffuse = vec3(0, 0, 0);
	if (nl > 0) {
		if (material.diffuseHasTexture) {
			diffuse = (texture(material.texture, fUv).rgb) * intensity * nl;
		} else {
			diffuse = (material.diffuseColor.rgb) * intensity  * nl;
		}	
	}
	vec3 specular = vec3(0, 0, 0);
	if (nl > 0) {
		vec3 h = normalize(l + fEye);
		float nhp =  pow(dot(normal, h), material.shininess);
		if (nhp > 0) {
			specular = material.specularColor.rgb * intensity * nhp;
		}
	}
	return diffuse + specular;
}

void main() {
	vec3 res = material.ambientColor;
	res += calcLight();

	fragColor = vec4(res, material.opacity);
	brightColor = vec4(0.0, 0.0, 0.0, 1.0);
}