#version 330 core
//Darkness Shader
//VERTEX SHADER

//Input: Die untransformierte Position
in vec3 position;
//Input: Die UV-Koordinaten (Falls Diffus-Textur)
in vec2 uv;
//Input: Normale
in vec3 normal;

//Out: UV
out vec2 fUv;
//Out: Normale
out vec3 fNormal;
//Out: Position
out vec3 fPosition;
out vec3 fEye;

//Uniform: Model-Matrix
uniform mat4 model;
//Uniform: Inverse Model-Matrix
uniform mat4 inverseModel;
//Uniform: ViewProjection-Matrix
uniform mat4 view_proj;
//Uniform: Kameraposition
uniform vec3 eyePos;

void main() {
	//MVP-Matrix anwenden
	gl_Position = view_proj * model * vec4(position, 1);
	vec4 xPosition = model * vec4(position, 1);
	//Welt-Position (ohne VP-Matrix) an Fragment-Shader weiterreichen
	fPosition = xPosition.xyz / xPosition.w;
	//UV-Koordinaten an Fragment-Shader weiterreichen
	fUv = uv;
	//Transformierte Normale und Richtung zum Auge weitergeben
	fNormal = normalize(mat3(transpose(inverseModel)) * normal);
	fEye = normalize(eyePos - fPosition);
}