#version 330 core
layout (location = 0) out vec4 fragColor;
layout (location = 1) out vec4 logColor;
in vec2 TexCoords;

uniform sampler2D scene;
uniform sampler2D bloomBlur;
uniform float intensity;
uniform sampler2D lastLogBuffer;
uniform bool hasLastLogBuffer;
uniform float deltaT;

void main()
{             
    vec3 originalColor = texture(scene, TexCoords).rgb;      
    vec3 bloomColor = texture(bloomBlur, TexCoords).rgb;
    originalColor += bloomColor; // additive blending
	originalColor *= intensity;
    fragColor = vec4(originalColor, 1.0f);
	logColor = vec4(log(0.00000001 + originalColor), 1);
	if (hasLastLogBuffer) {
		vec3 compare = texture(lastLogBuffer, TexCoords).rgb;
		vec3 change = logColor.rgb - compare;
		if (length(change) > deltaT * 8) {
			vec3 newChange = normalize(change) * deltaT * 8;
			logColor = vec4(compare + newChange, 1);
		}
	}
}